{% extends 'allianceauth/base-bs5.html' %}
{% load i18n %}
{% load static %}

{% block page_title %}{% translate "SOV Monitor" %}{% endblock %}
{% block header_nav_brand %}{% translate "Token registration" %}{% endblock %}

{% block extra_css %}<link rel="stylesheet" href="{% static 'holdfast/holdfast.css' %}">{% endblock %}

{% block header_nav_collapse_left %}
    <li class="nav-item"><a class="nav-link" href="{% url 'holdfast:sov_home' %}">{% translate "SOV" %}</a></li>
    <li class="nav-item"><a class="nav-link" href="{% url 'holdfast:skyhook_home' %}">{% translate "Skyhook" %}</a></li>
    <li class="nav-item"><a class="nav-link" href="{% url 'holdfast:den_home' %}">{% translate "Den" %}</a></li>
{% endblock %}

{% block content %}<div class="holdfast mb-3">{% block holdfast_content %}{% endblock %}</div>{% endblock %}
{% block extra_javascript %}<script src="{% static 'holdfast/holdfast.js' %}"></script>{% endblock %}
